Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Mechanical Turk.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon Mechanical Turk - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for Amazon Mechanical Turk

Amazon Mechanical Turk (service prefix: `mechanicalturk` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Mechanical Turk
- Resource Types Defined by Amazon Mechanical Turk
- Condition Keys for Amazon Mechanical Turk

## Actions Defined by Amazon Mechanical Turk

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AcceptQualificationRequest | The AcceptQualificationRequest operation grants a Worker's request for a Qualification | Write |  |  |
ApproveAssignment | The ApproveAssignment operation approves the results of a completed assignment | Write |  |  |
AssociateQualificationWithWorker | The AssociateQualificationWithWorker operation gives a Worker a Qualification | Write |  |  |
CreateAdditionalAssignmentsForHIT | The CreateAdditionalAssignmentsForHIT operation increases the maximum number of assignments of an existing HIT | Write |  |  |
CreateHIT | The CreateHIT operation creates a new HIT (Human Intelligence Task) | Write |  |  |
CreateHITType | The CreateHITType operation creates a new HIT type | Write |  |  |
CreateHITWithHITType | The CreateHITWithHITType operation creates a new Human Intelligence Task (HIT) using an existing HITTypeID generated by the CreateHITType operation | Write |  |  |
CreateQualificationType | The CreateQualificationType operation creates a new Qualification type, which is represented by a QualificationType data structure | Write |  |  |
CreateWorkerBlock | The CreateWorkerBlock operation allows you to prevent a Worker from working on your HITs | Write |  |  |
DeleteHIT | The DeleteHIT operation disposes of a HIT that is no longer needed | Write |  |  |
DeleteQualificationType | The DeleteQualificationType disposes a Qualification type and disposes any HIT types that are associated with the Qualification type | Write |  |  |
DeleteWorkerBlock | The DeleteWorkerBlock operation allows you to reinstate a blocked Worker to work on your HITs | Write |  |  |
DisassociateQualificationFromWorker | The DisassociateQualificationFromWorker revokes a previously granted Qualification from a user | Write |  |  |
GetAccountBalance | The GetAccountBalance operation retrieves the amount of money in your Amazon Mechanical Turk account | Read |  |  |
GetAssignment | The GetAssignment retrieves an assignment with an AssignmentStatus value of Submitted, Approved, or Rejected, using the assignment's ID | Read |  |  |
GetFileUploadURL | The GetFileUploadURL operation generates and returns a temporary URL | Read |  |  |
GetHIT | The GetHIT operation retrieves the details of the specified HIT | Read |  |  |
GetQualificationScore | The GetQualificationScore operation returns the value of a Worker's Qualification for a given Qualification type | Read |  |  |
GetQualificationType | The GetQualificationType operation retrieves information about a Qualification type using its ID | Read |  |  |
ListAssignmentsForHIT | The ListAssignmentsForHIT operation retrieves completed assignments for a HIT | List |  |  |
ListBonusPayments | The ListBonusPayments operation retrieves the amounts of bonuses you have paid to Workers for a given HIT or assignment | List |  |  |
ListHITs | The ListHITs operation returns all of a Requester's HITs | List |  |  |
ListHITsForQualificationType | The ListHITsForQualificationType operation returns the HITs that use the given QualififcationType for a QualificationRequirement | List |  |  |
ListQualificationRequests | The ListQualificationRequests operation retrieves requests for Qualifications of a particular Qualification type | List |  |  |
ListQualificationTypes | The ListQualificationTypes operation searches for Qualification types using the specified search query, and returns a list of Qualification types | List |  |  |
ListReviewPolicyResultsForHIT | The ListReviewPolicyResultsForHIT operation retrieves the computed results and the actions taken in the course of executing your Review Policies during a CreateHIT operation | List |  |  |
ListReviewableHITs | The ListReviewableHITs operation returns all of a Requester's HITs that have not been approved or rejected | List |  |  |
ListWorkerBlocks | The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs | List |  |  |
ListWorkersWithQualificationType | The ListWorkersWithQualificationType operation returns all of the Workers with a given Qualification type | List |  |  |
NotifyWorkers | The NotifyWorkers operation sends an email to one or more Workers that you specify with the Worker ID | Write |  |  |
RejectAssignment | The RejectAssignment operation rejects the results of a completed assignment | Write |  |  |
RejectQualificationRequest | The RejectQualificationRequest operation rejects a user's request for a Qualification | Write |  |  |
SendBonus | The SendBonus operation issues a payment of money from your account to a Worker | Write |  |  |
SendTestEventNotification | The SendTestEventNotification operation causes Amazon Mechanical Turk to send a notification message as if a HIT event occurred, according to the provided notification specification | Write |  |  |
UpdateExpirationForHIT | The UpdateExpirationForHIT operation allows you extend the expiration time of a HIT beyond is current expiration or expire a HIT immediately | Write |  |  |
UpdateHITReviewStatus | The UpdateHITReviewStatus operation toggles the status of a HIT | Write |  |  |
UpdateHITTypeOfHIT | The UpdateHITTypeOfHIT operation allows you to change the HITType properties of a HIT | Write |  |  |
UpdateNotificationSettings | The UpdateNotificationSettings operation creates, updates, disables or re-enables notifications for a HIT type | Write |  |  |
UpdateQualificationType | The UpdateQualificationType operation modifies the attributes of an existing Qualification type, which is represented by a QualificationType data structure | Write |  |  |

## Resource Types Defined by Amazon Mechanical Turk

Amazon Mechanical Turk does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon Mechanical Turk, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon Mechanical Turk

MechanicalTurk has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.